@@ -20,18 +20,22 @@ from silly_db.selections import (
     Selection,
     SelectionItem,
     Model,
-    VirtualModel,
 )
 
 
 class DB:
     """Central object interacting with the database itself.
     params:
+        - base: the absolute path on wich 'file' and 'migrations_dir' are
+        relatives to.
         - file (required): path to your desired [name].sqlite3 file
-        - debug: default is True, shows or not some warnings.
+        - migrations_dir: path to the directory containing the migrations
+        - debug: default is 'True', shows some warnings in console.
+         'False' will hide the warnings.
     """
     def __init__(
         self,
+        base=None,
         file: str = None,
         migrations_dir: str = None,
         debug: bool = True
@@ -39,10 +43,10 @@ class DB:
         if file is None:
             raise SillyDbError(
                 "Missing parameter for DB: file=some_file_name.sqlite3")
-        self.file = file
-        self.connection = sqlite3.connect(file)
+        self.file = os.path.join(base, file)
+        self.connection = sqlite3.connect(self.file)
         self.cursor = self.connection.cursor()
-        self.migrations_dir = migrations_dir
+        self.migrations_dir = os.path.join(base, migrations_dir)
         self.debug = debug
 
         self.execute(INITIALIZE_DB)
@@ -112,11 +116,12 @@ class DB:
                     f"VALUES('{file_name}', '{sha1}');"
                 )
                 self.execute(register_migration)
-                print(
-                    color["success"] +
-                    f"Migration successfully applied: {file_name}" +
-                    color['end']
-                    )
+                if self.debug:
+                    print(
+                        color["success"] +
+                        f"Migration successfully applied: {file_name}" +
+                        color['end']
+                        )
             except sqlite3.OperationalError as e:
                 print("sqlite3.OperationalError :")
                 print(e)
@@ -132,7 +137,7 @@ class DB:
             apply_dir = self.migrations_dir
         files = [
             file for file in os.listdir(apply_dir)
-            if file.lower().endswith(".sql")
+            if file.endswith(".sql")
             ]
         files.sort()
         for file in files:
@@ -195,10 +200,6 @@ class DB:
                     f.write(f"{line[0]};\n")
             f.write("COMMIT;")
 
-    def view(self, *args):
-        """returns a VirtualModel object"""
-        return VirtualModel(self, *args)
-
     def query(self, command: str) -> Selection:
         """command is a SQL query, returns a Selection object"""
         self.cursor.execute(command)
