@@ -6,5 +6,5 @@ class SillyDbError(Exception):
 MIGRATE_ALL_ERROR = (
     "No migrations directory have been defined, do it when créating the "
     "database :\n"
-    "db = DB(base_dir=[some_dir], file=[some_file], migrations_dir=[THIS DIR]"
+    "db = DB(base=[some_dir], file=[some_file], migrations_dir=[THIS DIR]"
 )
